pub enum DataType {
Float64,
Float32,
UInt64,
UInt32,
Int64,
Int32,
IntStr,
Decimal256,
Decimal128,
}Expand description
DataType is an enumeration representing the different data types that can be used in the column mapping.
Each variant corresponds to a specific data type.
Variants