RateLimitResponse

Enum RateLimitResponse 

pub enum RateLimitResponse<T = ResponseData> {
    Success {
        response: QueryResponse<T>,
        rate_limit: RateLimitInfo,
    },
    RateLimited(RateLimitInfo),
}
Response from a _with_rate_limit method.

On a successful query the Success variant contains both the response data and the rate limit headers. When the server responds with HTTP 429, the RateLimited variant is returned immediately (without internal retry) so the caller can implement their own back-off.

Variants



Success

The query succeeded.

Fields

response: QueryResponse<T>

The query response data.

rate_limit: RateLimitInfo

Rate limit information from response headers (if present).



RateLimited(RateLimitInfo)

The server responded with 429 Too Many Requests.