ClientConfig

Struct ClientConfig 

pub struct ClientConfig {
    pub url: String,
    pub api_token: String,
    pub http_req_timeout_millis: u64,
    pub max_num_retries: usize,
    pub retry_backoff_ms: u64,
    pub retry_base_ms: u64,
    pub retry_ceiling_ms: u64,
    pub serialization_format: SerializationFormat,
    pub proactive_rate_limit_sleep: bool,
}
Configuration for the hypersync client.

Fields

url: String

HyperSync server URL.

api_token: String

HyperSync server api token.

http_req_timeout_millis: u64

Milliseconds to wait for a response before timing out.

max_num_retries: usize

Number of retries to attempt before returning error.

retry_backoff_ms: u64

Milliseconds that would be used for retry backoff increasing.

retry_base_ms: u64

Initial wait time for request backoff.

retry_ceiling_ms: u64

Ceiling time for request backoff.

serialization_format: SerializationFormat

Query serialization format to use for HTTP requests.

proactive_rate_limit_sleep: bool

Whether to proactively sleep when the rate limit is exhausted instead of sending requests that will be rejected with 429.

Enabled by default. Set to false to opt out and handle rate limits yourself.

Implementations

Source

impl ClientConfig

pub const fn default_http_req_timeout_millis() -> u64

Default HTTP request timeout in milliseconds

pub const fn default_max_num_retries() -> usize

Default maximum number of retries

pub const fn default_retry_backoff_ms() -> u64

Default retry backoff in milliseconds

pub const fn default_retry_base_ms() -> u64

Default retry base time in milliseconds

pub const fn default_retry_ceiling_ms() -> u64

Default retry ceiling time in milliseconds

pub const fn default_proactive_rate_limit_sleep() -> bool

Default proactive rate limit sleep setting

pub fn validate(&self) -> Result<()>

Validates the config