EventResponse

Type Alias EventResponse 

pub type EventResponse = QueryResponse<Vec<Event>>;
Alias for Event oriented, vectorized QueryResponse

Aliased Type

pub struct EventResponse {
    pub archive_height: Option<u64>,
    pub next_block: u64,
    pub total_execution_time: u64,
    pub data: Vec<Event>,
    pub rollback_guard: Option<RollbackGuard>,
}

Fields

archive_height: Option<u64>

Current height of the source hypersync instance

next_block: u64

Next block to query for, the responses are paginated so the caller should continue the query from this block if they didn’t get responses up to the to_block they specified in the Query.

total_execution_time: u64

Total time it took the hypersync instance to execute the query.

data: Vec<Event>

Response data

rollback_guard: Option<RollbackGuard>

Rollback guard